@@ -266,7 +266,12 @@ function _eigsolve(
     vals = diag(view(Tₘ, 1:k, 1:k))
     VR = _schur_right_eigenvectors(Tₘ, k)
     mul!(cache1₁ₖ, Vₘ, M(Uₘ * VR))
-    vecs = copy(cache1₁ₖ)
+
+    # Order the eigenvalues and eigenvectors
+    idxs = sortperm(vals, by = sortby, rev = rev)
+    vals = vals[idxs]
+    vecs = cache1₁ₖ[:, idxs]
+
     settings.auto_tidyup && tidyup!(vecs)
 
     return EigsolveResult(vals, vecs, type, dimensions, iter, numops, (iter < maxiter))
@@ -275,7 +280,7 @@ end
 @doc raw"""
     eigsolve(A::QuantumObject; 
         v0::Union{Nothing,AbstractVector}=nothing, 
-        sigma::Union{Nothing, Real}=nothing,
+        sigma::Union{Nothing, Number}=nothing,
         eigvals::Int = 1,
         krylovdim::Int = max(20, 2*k+1),
         tol::Real = 1e-8,
@@ -290,7 +295,7 @@ Solve for the eigenvalues and eigenvectors of a matrix `A` using the Arnoldi met
 # Arguments
 - `A::QuantumObject`: the [`QuantumObject`](@ref) to solve eigenvalues and eigenvectors.
 - `v0::Union{Nothing,AbstractVector}`: the initial vector for the Arnoldi method. Default is a random vector.
-- `sigma::Union{Nothing, Real}`: the shift for the eigenvalue problem. Default is `nothing`.
+- `sigma::Union{Nothing, Number}`: the shift for the eigenvalue problem. Default is `nothing`.
 - `eigvals::Int`: the number of eigenvalues to compute. Default is `1`.
 - `krylovdim::Int`: the dimension of the Krylov subspace. Default is `max(20, 2*k+1)`.
 - `tol::Real`: the tolerance for the Arnoldi method. Default is `1e-8`.
@@ -309,7 +314,7 @@ Solve for the eigenvalues and eigenvectors of a matrix `A` using the Arnoldi met
 function eigsolve(
     A::QuantumObject;
     v0::Union{Nothing,AbstractVector} = nothing,
-    sigma::Union{Nothing,Real} = nothing,
+    sigma::Union{Nothing,Number} = nothing,
     eigvals::Int = 1,
     krylovdim::Int = max(20, 2 * eigvals + 1),
     tol::Real = 1e-8,
@@ -341,7 +346,7 @@ function eigsolve(
     v0::Union{Nothing,AbstractVector} = nothing,
     type::Union{Nothing,Operator,SuperOperator} = nothing,
     dimensions = nothing,
-    sigma::Union{Nothing,Real} = nothing,
+    sigma::Union{Nothing,Number} = nothing,
     eigvals::Int = 1,
     krylovdim::Int = max(20, 2 * eigvals + 1),
     tol::Real = 1e-8,
@@ -352,10 +357,9 @@ function eigsolve(
     kwargs...,
 )
     T = eltype(A)
-    isH = ishermitian(A)
-    v0 === nothing && (v0 = normalize!(rand(T, size(A, 1))))
+    isnothing(v0) && (v0 = normalize!(rand(T, size(A, 1))))
 
-    if sigma === nothing
+    if isnothing(sigma)
         res = _eigsolve(
             A,
             v0,
@@ -371,17 +375,24 @@ function eigsolve(
         vals = res.values
     else
         Aₛ = A - sigma * I
-        solver === nothing && (solver = isH ? KrylovJL_MINRES() : KrylovJL_GMRES())
 
         kwargs2 = (; kwargs...)
-        condition = !haskey(kwargs2, :Pl) && typeof(A) <: SparseMatrixCSC
-        condition && (kwargs2 = merge(kwargs2, (Pl = ilu(Aₛ, τ = 0.01),)))
 
         !haskey(kwargs2, :abstol) && (kwargs2 = merge(kwargs2, (abstol = tol * 1e-6,)))
         !haskey(kwargs2, :reltol) && (kwargs2 = merge(kwargs2, (reltol = tol * 1e-6,)))
+        !haskey(kwargs2, :assumptions) && (kwargs2 = merge(kwargs2, (assumptions = OperatorAssumptions(true),)))
 
-        prob = LinearProblem(Aₛ, v0)
-        linsolve = init(prob, solver; kwargs2...)
+        prob = LinearProblem{true}(Aₛ, v0)
+
+        linsolve = if isnothing(solver)
+            if typeof(A) <: SparseMatrixCSC && isprimitivetype(T)
+                init(prob, UMFPACKFactorization(); kwargs2...)
+            else
+                init(prob; kwargs2...)
+            end
+        else
+            init(prob, solver; kwargs2...)
+        end
 
         Amap = EigsolveInverseMap(T, size(A), linsolve)
 
@@ -411,7 +422,7 @@ end
         H::Union{AbstractQuantumObject{HOpType},Tuple},
         T::Real,
         c_ops::Union{Nothing,AbstractVector,Tuple} = nothing;
-        alg::OrdinaryDiffEqAlgorithm = Tsit5(),
+        alg::AbstractODEAlgorithm = DP5(),
         params::NamedTuple = NamedTuple(),
         ρ0::AbstractMatrix = rand_dm(prod(H.dimensions)).data,
         eigvals::Int = 1,
@@ -429,7 +440,7 @@ Solve the eigenvalue problem for a Liouvillian superoperator `L` using the Arnol
 - `H`: The Hamiltonian (or directly the Liouvillian) of the system. It can be a [`QuantumObject`](@ref), a [`QuantumObjectEvolution`](@ref), or a tuple of the form supported by [`mesolve`](@ref).
 - `T`: The time at which to evaluate the time evolution.
 - `c_ops`: A vector of collapse operators. Default is `nothing` meaning the system is closed.
-- `alg`: The differential equation solver algorithm. Default is `Tsit5()`.
+- `alg`: The differential equation solver algorithm. Default is `DP5()`.
 - `params`: A `NamedTuple` containing the parameters of the system.
 - `ρ0`: The initial density matrix. If not specified, a random density matrix is used.
 - `eigvals`: The number of eigenvalues to compute.
@@ -454,7 +465,7 @@ function eigsolve_al(
     H::Union{AbstractQuantumObject{HOpType},Tuple},
     T::Real,
     c_ops::Union{Nothing,AbstractVector,Tuple} = nothing;
-    alg::OrdinaryDiffEqAlgorithm = Tsit5(),
+    alg::AbstractODEAlgorithm = DP5(),
     params::NamedTuple = NamedTuple(),
     ρ0::AbstractMatrix = rand_dm(prod(H.dimensions)).data,
     eigvals::Int = 1,
