@@ -111,19 +111,20 @@ function ssesolveProblem(
         sc_ops_evo_data,
     )
 
-    K = get_data(-1im * QuantumObjectEvolution(H_eff_evo)) + K_l
+    K = cache_operator(get_data(-1im * QuantumObjectEvolution(H_eff_evo)) + K_l, ψ0)
 
     D_l = map(op -> op + _ScalarOperator_e(op, -) * IdentityOperator(prod(dims)), sc_ops_evo_data)
     D = DiffusionOperator(D_l)
 
     kwargs2 = _merge_saveat(tlist, e_ops, DEFAULT_SDE_SOLVER_OPTIONS; kwargs...)
-    kwargs3 = _generate_stochastic_kwargs(
+    kwargs3 = _merge_tstops(kwargs2, isconstant(K), tlist)
+    kwargs4 = _generate_stochastic_kwargs(
         e_ops,
         sc_ops_list,
         makeVal(progress_bar),
         tlist,
         makeVal(store_measurement),
-        kwargs2,
+        kwargs3,
         SaveFuncSSESolve,
     )
 
@@ -138,7 +139,7 @@ function ssesolveProblem(
         params;
         noise_rate_prototype = noise_rate_prototype,
         noise = noise,
-        kwargs3...,
+        kwargs4...,
     )
 
     return TimeEvolutionProblem(prob, tlist, dims)
@@ -280,7 +281,7 @@ end
         ψ0::QuantumObject{Ket},
         tlist::AbstractVector,
         sc_ops::Union{Nothing,AbstractVector,Tuple,AbstractQuantumObject} = nothing;
-        alg::Union{Nothing,StochasticDiffEqAlgorithm} = nothing,
+        alg::Union{Nothing,AbstractSDEAlgorithm} = nothing,
         e_ops::Union{Nothing,AbstractVector,Tuple} = nothing,
         params = NullParameters(),
         rng::AbstractRNG = default_rng(),
@@ -357,7 +358,7 @@ function ssesolve(
     ψ0::QuantumObject{Ket},
     tlist::AbstractVector,
     sc_ops::Union{Nothing,AbstractVector,Tuple,AbstractQuantumObject} = nothing;
-    alg::Union{Nothing,StochasticDiffEqAlgorithm} = nothing,
+    alg::Union{Nothing,AbstractSDEAlgorithm} = nothing,
     e_ops::Union{Nothing,AbstractVector,Tuple} = nothing,
     params = NullParameters(),
     rng::AbstractRNG = default_rng(),
@@ -398,7 +399,7 @@ end
 
 function ssesolve(
     ens_prob::TimeEvolutionProblem,
-    alg::StochasticDiffEqAlgorithm = SRA2(),
+    alg::AbstractSDEAlgorithm = SRA2(),
     ntraj::Int = 500,
     ensemblealg::EnsembleAlgorithm = EnsembleThreads(),
     keep_runs_results = Val(false),
