@@ -62,6 +62,7 @@ end
 
 @testitem "sesolve" setup=[TESetup] begin
     using SciMLOperators
+    import SciMLOperators: ScaledOperator
 
     # Get parameters from TESetup to simplify the code
     H = TESetup.H
@@ -82,7 +83,8 @@ end
     amp_rabi = TESetup.g^2 / Ω_rabi^2
     ##
 
-    @test prob.prob.f.f isa MatrixOperator
+    @test prob.prob.f.f isa ScaledOperator
+    @test !haskey(prob.prob.kwargs, :tstops) # tstops should not exist for time-independent cases
     @test sum(abs.(sol.expect[1, :] .- amp_rabi .* sin.(Ω_rabi * tlist) .^ 2)) / length(tlist) < 0.1
     @test length(sol.times) == length(tlist)
     @test length(sol.times_states) == 1
@@ -133,7 +135,7 @@ end
 
         allocs_tot = @allocations sesolve(H, ψ0, tlist, saveat = [tlist[end]], progress_bar = Val(false)) # Warm-up
         allocs_tot = @allocations sesolve(H, ψ0, tlist, saveat = [tlist[end]], progress_bar = Val(false))
-        @test allocs_tot < 90
+        @test allocs_tot < 95
     end
 
     @testset "Type Inference sesolve" begin
@@ -222,6 +224,7 @@ end
     sol_me5 = mesolve(H, ψ0, tlist, progress_bar = Val(false))
 
     @test TESetup.prob_me.prob.f.f isa MatrixOperator
+    @test !haskey(TESetup.prob_me.prob.kwargs, :tstops) # tstops should not exist for time-independent cases
     @test isket(sol_me5.states[1])
     @test length(sol_me.times) == length(tlist)
     @test length(sol_me.times_states) == 1
@@ -390,6 +393,7 @@ end
 
 @testitem "mcsolve" setup=[TESetup] begin
     using SciMLOperators
+    import SciMLOperators: ScaledOperator
     using Statistics
 
     # Get parameters from TESetup to simplify the code
@@ -432,7 +436,8 @@ end
     expect_mc_states_mean = expect.(Ref(e_ops[1]), average_states(sol_mc_states))
     expect_mc_states_mean2 = expect.(Ref(e_ops[1]), average_states(sol_mc_states2))
 
-    @test prob_mc.prob.f.f isa MatrixOperator
+    @test prob_mc.prob.f.f isa ScaledOperator
+    @test !haskey(prob_mc.prob.kwargs, :tstops) # tstops should not exist for time-independent cases
     @test sum(abs, sol_mc.expect .- sol_me.expect) / length(tlist) < 0.1
     @test sum(abs, sol_mc2.expect .- sol_me.expect) / length(tlist) < 0.1
     @test sum(abs, average_expect(sol_mc3) .- sol_me.expect) / length(tlist) < 0.1
@@ -523,7 +528,7 @@ end
                 progress_bar = Val(false),
                 keep_runs_results = Val(true),
             )
-            @test allocs_tot < n1 * ntraj + 400 # 150 allocations per trajectory + 500 for initialization
+            @test allocs_tot < n1 * ntraj + 600 # 150 allocations per trajectory + 600 for initialization
 
             allocs_tot = @allocations mcsolve(
                 H,
@@ -1046,6 +1051,11 @@ end
     @test sol_me.expect ≈ sol_me_td2.expect atol = 1e-6 * length(tlist)
     @test sol_mc.expect ≈ sol_mc_td2.expect atol = 1e-2 * length(tlist)
     # @test sol_sse.expect ≈ sol_sse_td2.expect atol = 1e-2 * length(tlist)
+
+    # test assume_hermitian = Val(false)
+    L_td_non_herm = liouvillian(H_td2, c_ops, assume_hermitian = Val(false))
+    sol_me_td3 = mesolve(L_td_non_herm, ψ0, tlist, e_ops = e_ops, progress_bar = Val(false), params = p)
+    @test sol_me.expect ≈ sol_me_td3.expect atol = 1e-6 * length(tlist)
 end
 
 @testitem "mcsolve, ssesolve and smesolve reproducibility" setup=[TESetup] begin
@@ -1172,7 +1182,7 @@ end
     @test sol_sme1.expect ≈ sol_sme3.expect[:, 1:50, :] atol = 1e-10
 end
 
-@testitem "example" begin
+@testitem "Example: Two qubit model" begin
     sp1 = kron(sigmap(), qeye(2))
     sm1 = sp1'
     sx1 = sm1 + sp1
@@ -1196,3 +1206,76 @@ end
     @test sum(abs.(sol_mc.expect[1:2, :] .- sol_me.expect[1:2, :])) / length(t_l) < 0.1
     @test expect(sp1 * sm1, sol_me.states[end]) ≈ expect(sigmap() * sigmam(), ptrace(sol_me.states[end], 1))
 end
+
+@testitem "Example: Qubit driven by two sequential cosine pulses" begin
+    # settings of pulses
+    A1 = rand() # Rabi amplitude of pulse 1
+    A2 = rand() # Rabi amplitude of pulse 2
+    t1 = 0 # starting time of pulse 1
+    t2 = 100 # starting time of pulse 2
+    T = 10 # duration of each pulse
+    pulse1(p, t) = ((t1 <= t) && (t <= t1 + T)) ? (0.5 * p.A1 * π / T) * (1 - cos(2π * (t - t1) / T)) : 0
+    pulse2(p, t) = ((t2 <= t) && (t <= t2 + T)) ? (0.5 * p.A2 * π / T) * (1 - cos(2π * (t - t2) / T)) : 0
+
+    # time‐dependent Hamiltonian
+    σy = sigmay()
+    H = QobjEvo(σy, pulse1) + QobjEvo(σy, pulse2)
+
+    # initial state
+    ψ0 = basis(2, 0)
+    ρ0 = ket2dm(ψ0) # to force using mesolve
+
+    # sesolve & mesolve
+    tlist = range(0.0, stop = 140.0, length = 10000) # don't change tlist, to check the second pulse contribute correctly under 'tstops=tlist' setting
+    e_ops = [sigmax(), sigmaz()]
+    params = (A1 = A1, A2 = A2)
+    prob_se = sesolveProblem(H, ψ0, tlist; e_ops = e_ops, params = params, progress_bar = Val(false))
+    prob_me = mesolveProblem(H, ρ0, tlist; e_ops = e_ops, params = params, progress_bar = Val(false))
+    sol_se = sesolve(prob_se)
+    sol_me = mesolve(prob_me)
+
+    # analytic solution
+    function θ(t, t_start, A)
+        # a dummy comment to avoid julia formatter
+        if t < t_start
+            return 0
+        elseif (t_start <= t) && (t <= t_start + T)
+            return (A * π / T) * (t - t_start - (T * sin(2π * (t - t_start) / T) / (2π)))
+        else
+            return A * π
+        end
+    end
+    θlist = θ.(tlist, t1, A1) + θ.(tlist, t2, A2)
+    X_analytic = sin.(θlist)
+    Z_analytic = cos.(θlist)
+
+    @test prob_se.prob.kwargs[:tstops] == tlist # tstops should be equal to tlist for time-dependent cases
+    @test prob_me.prob.kwargs[:tstops] == tlist # tstops should be equal to tlist for time-dependent cases
+    @test all(isapprox.(X_analytic, sol_se.expect[1, :]; atol = 1e-6))
+    @test all(isapprox.(X_analytic, sol_me.expect[1, :]; atol = 1e-6))
+    @test all(isapprox.(Z_analytic, sol_se.expect[2, :]; atol = 1e-6))
+    @test all(isapprox.(Z_analytic, sol_me.expect[2, :]; atol = 1e-6))
+end
+
+@testitem "ComposedOperator support in time evolution" begin
+    N = 10  # number of basis states
+    a = destroy(N)
+    H = a' * a
+
+    ψ0 = basis(N, 9)  # initial state
+
+    γ0 = 0.5
+    γ1(p, t) = sqrt(p[1] * exp(-t))
+    c_ops_1 = [QobjEvo(2a, γ1)] # This generates a ScaledOperator internally
+    c_ops_2 = [QobjEvo(a, γ1) + QobjEvo(a, γ1)] # This generates a ComposedOperator internally
+
+    e_ops = [a' * a]
+
+    tlist = range(0, 10, 100)
+    params = [γ0]
+    sol_1 = mesolve(H, ψ0, tlist, c_ops_1, e_ops = e_ops; progress_bar = Val(false), params = params, saveat = tlist)
+    sol_2 = mesolve(H, ψ0, tlist, c_ops_2, e_ops = e_ops; progress_bar = Val(false), params = params, saveat = tlist)
+
+    @test sol_1.expect[1, :] ≈ sol_2.expect[1, :] atol=1e-10
+    @test all(x -> isapprox(x[1].data, x[2].data; atol = 1e-10), zip(sol_1.states, sol_2.states))
+end
