@@ -74,7 +74,8 @@ if (GROUP == "CUDA_Ext")
     import StaticArraysCore: SVector
     using CUDA
     using CUDA.CUSPARSE
-    # CUDA.allowscalar(false) # This is already set in the extension script
+    using CUDSS
+    using LinearSolve
 
     QuantumToolbox.about()
     CUDA.versioninfo()
@@ -88,7 +89,9 @@ if (GROUP == "Arbitrary-Precision")
     Pkg.update()
 
     using QuantumToolbox
+    using LinearAlgebra
     using SparseArrays
+    using Sparspak
     using GenericSchur
 
     QuantumToolbox.about()
